summaryrefslogtreecommitdiffstats
path: root/sys/kern/kern_sig.c
diff options
context:
space:
mode:
Diffstat (limited to 'sys/kern/kern_sig.c')
-rw-r--r--sys/kern/kern_sig.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/sys/kern/kern_sig.c b/sys/kern/kern_sig.c
index ea2ab15..9bf4385 100644
--- a/sys/kern/kern_sig.c
+++ b/sys/kern/kern_sig.c
@@ -1256,19 +1256,19 @@ pgsignal(pgrp, sig, checkctty)
}
/*
* Send a signal caused by a trap to the current process.
* If it will be caught immediately, deliver it with correct code.
* Otherwise, post it normally.
*
* MPSAFE
*/
void
-trapsignal(p, sig, code)
- struct proc *p;
- register int sig;
- u_long code;
+trapsignal(struct thread *td, int sig, u_long code)
{
- register struct sigacts *ps;
+ struct sigacts *ps;
+ struct proc *p;
+
+ p = td->td_proc;
PROC_LOCK(p);
ps = p->p_sigacts;
OpenPOWER on IntegriCloud
@@ -1256,19 +1256,19 @@ pgsignal(pgrp, sig, checkctty)
}
/*
- * Send a signal caused by a trap to the current process.
+ * Send a signal caused by a trap to the current thread.
* If it will be caught immediately, deliver it with correct code.
* Otherwise, post it normally.